@@ -21,21 +21,8 @@ from django.contrib.gis.db.models.fields import GeometryField
 
 class DjangoGeoJSONEncoder(DjangoJSONEncoder):
 
-    DATE_FORMAT = '%Y-%m-%d'
-    TIME_FORMAT = '%H:%M:%S'
-
     def default(self, o):
-        if isinstance(o, datetime.datetime):
-            d = datetime_safe.new_datetime(o)
-            return d.strftime("%s %s" % (self.DATE_FORMAT, self.TIME_FORMAT))
-        elif isinstance(o, datetime.date):
-            d = datetime_safe.new_date(o)
-            return d.strftime(self.DATE_FORMAT)
-        elif isinstance(o, datetime.time):
-            return o.strftime(self.TIME_FORMAT)
-        elif isinstance(o, decimal.Decimal):
-            return float(o)
-        elif isinstance(o, GEOSGeometry):
+        if isinstance(o, GEOSGeometry):
             return json.loads(o.geojson)
         else:
             return super(DjangoGeoJSONEncoder, self).default(o)
@@ -92,15 +79,11 @@ class GeoJSONSerializer(PythonSerializer):
             value = field._get_val_from_obj(obj)
             field_name = field.name
 
-        if isinstance(value, GEOSGeometry):
+        if field_name == self.geometry_field and isinstance(value, GEOSGeometry):
             # ignore other geometries, only one geometry per feature
-            if field_name == self.geometry_field:
-                self._current['geometry'] = value
-        
-        elif not is_protected_type(value):
-            value = field.value_to_string(obj)
+            self._current['geometry'] = value
 
-        if self.properties and \
+        elif self.properties and \
             field_name in self.properties:
             # set the field name to the key's value mapping in self.properties
             if isinstance(self.properties, dict):
